@@ -6,11 +6,28 @@ import numpy as np
 
 
 class Solution():
+    """Solution class
+
+    Args:
+        listVars (list): Range list
+        functionToEvaluate (funtion): Function to minimize or maximize
+        listConstraints (list, optional): Constraint list. Defaults to [].
+    """
 
     def __repr__(self):
+        """Represent
+
+        Returns:
+            str: Solution represent
+        """
         return self.__str__()
 
     def __str__(self):
+        """Str
+
+        Returns:
+            str: Solution represent
+        """
         return str(self.solution)
 
     def __init__(self, listVars, functionToEvaluate, listConstraints=[]):
@@ -24,7 +41,9 @@ class Solution():
         self.value = None
 
     def generate(self):
-        while 1:
+        """Generate a solution"""
+
+        while True:
             solution = np.zeros(self.cantVars)
             for item in range(self.cantVars):
                 solution[item] = self.listVars[item].get()
@@ -32,17 +51,34 @@ class Solution():
                 self.solution = solution
                 break
         self.value = self.evaluate()
-        # print("solution.generate:", self.solution)
 
     def constraintsOK(self, solution):
+        """Check that the solution satisfies the constraints
+
+        Args:
+            solution (Solution): Solution to check
+
+        Returns:
+            Bool: True if it satisfies the constraints, False if not
+        """
         for constraints in self.listConstraints:
             if not constraints(*[solution]):
                 return False
         return True
 
     def evaluate(self):
+        """Evaluate the solution
+
+        Returns:
+            Float: Result when evaluating the solution
+        """
         return self.functionToEvaluate(*[self.solution])
 
     def setSolution(self, solution):
+        """Set solution
+
+        Args:
+            solution (Solution): Solution to be assigned
+        """
         self.solution = solution
         self.value = self.evaluate()
